define(
//begin v1.x content
{
	"HKD_displayName": "Гонконгский доллар",
	"CNY_displayName": "Китайский юань",
	"JPY_displayName": "Японская иена",
	"JPY_symbol": "¥",
	"USD_displayName": "Доллар США",
	"CAD_symbol": "CA$",
	"GBP_displayName": "Британский фунт стерлингов",
	"CHF_displayName": "Швейцарский франк",
	"CNY_symbol": "CN¥",
	"EUR_displayName": "Евро",
	"GBP_symbol": "£",
	"CAD_displayName": "Канадский доллар",
	"USD_symbol": "$",
	"EUR_symbol": "€",
	"AUD_displayName": "Австралийский доллар",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "A$"
}
//end v1.x content
);